@@ -20,9 +20,9 @@
 #include "manager_p.h"
 
 #include <QDBusConnection>
+#include <QDebug>
 
 #include <ktoolinvocation.h>
-#include <kdebug.h>
 
 namespace KActivities {
 
@@ -47,6 +47,13 @@ Manager::Manager()
             QDBusConnection::sessionBus(),
             this
             )),
+      m_resourcesLinking(
+          new org::kde::ActivityManager::ResourcesLinking(
+            ACTIVITY_MANAGER_DBUS_PATH,
+            ACTIVITY_MANAGER_DBUS_OBJECT "/Resources/Linking",
+            QDBusConnection::sessionBus(),
+            this
+            )),
       m_features(
           new org::kde::ActivityManager::Features(
             ACTIVITY_MANAGER_DBUS_PATH,
@@ -70,13 +77,13 @@ Manager * Manager::self()
 
             int ret = KToolInvocation::startServiceByDesktopPath("kactivitymanagerd.desktop", QStringList(), &error);
             if (ret > 0) {
-                kDebug() << "Activity: Couldn't start kactivitymanagerd: " << error << endl;
+                qDebug() << "Activity: Couldn't start kactivitymanagerd: " << error << endl;
             }
 
             if (!QDBusConnection::sessionBus().interface()->isServiceRegistered(ACTIVITY_MANAGER_DBUS_PATH)) {
-                kDebug() << "Activity: The kactivitymanagerd service is still not registered";
+                qDebug() << "Activity: The kactivitymanagerd service is still not registered";
             } else {
-                kDebug() << "Activity: The kactivitymanagerd service has been registered";
+                qDebug() << "Activity: The kactivitymanagerd service has been registered";
             }
         }
 
@@ -111,6 +118,11 @@ Service::Resources * Manager::resources()
     return self()->m_resources;
 }
 
+Service::ResourcesLinking * Manager::resourcesLinking()
+{
+    return self()->m_resourcesLinking;
+}
+
 Service::Features * Manager::features()
 {
     return self()->m_features;
