@@ -22,23 +22,17 @@
 #include "resourcesadaptor.h"
 
 #include <QDBusConnection>
-#include <QList>
 #include <QThread>
 #include <QMutex>
 #include <QMutexLocker>
+#include <QDebug>
 
 #include <KUrl>
-#include <KDebug>
 #include <KWindowSystem>
 
 #include <Application.h>
 #include <Activities.h>
 
-#include <NepomukActivityManager.h>
-
-#include "jobs/encryption/all.h"
-#include "jobs/nepomuk/all.h"
-
 #include <time.h>
 
 #include "common.h"
@@ -46,49 +40,15 @@
 #include <utils/d_ptr_implementation.h>
 #include <utils/remove_if.h>
 
-static QString CurrentActivity()
-{
-    return Application::self()->activities().CurrentActivity();
-}
-
-// Convenience functions that check whether the proper activity id is passed
-// and invokes the desired lambda/functor on that value is nepomuk is present
-template <typename Result, typename Function>
-static Result doWithNepomukForActivity(const QString & _activity, Function doWhat, Result noNepomukResult)
-{
-    #ifdef HAVE_NEPOMUK
-        if (NEPOMUK_PRESENT) {
-            const QString & activity = _activity.isEmpty() ? CurrentActivity() : _activity;
-            return doWhat(activity);
-
-        } else return noNepomukResult;
-
-    #else
-        Q_UNUSED(_activity)
-        Q_UNUSED(doWhat)
-        return noNepomukResult;
-
-    #endif
-}
-
-template <typename Function>
-static void doWithNepomukForActivity(const QString & _activity, Function doWhat)
-{
-    #ifdef HAVE_NEPOMUK
-        if (NEPOMUK_PRESENT) {
-            const QString & activity = _activity.isEmpty() ? CurrentActivity() : _activity;
-            doWhat(activity);
-        }
-    #endif
-}
-
 Resources::Private::Private(Resources * parent)
     : QThread(parent), focussedWindow(0), q(parent)
 {
 }
 
-static EventList events;
-static QMutex events_mutex;
+namespace {
+    EventList events;
+    QMutex events_mutex;
+}
 
 void Resources::Private::run()
 {
@@ -102,7 +62,7 @@ void Resources::Private::run()
             QMutexLocker locker(& events_mutex);
 
             if (events.count() == 0) {
-                // kDebug() << "No more events to process, exiting.";
+                // qDebug() << "No more events to process, exiting.";
                 return;
             }
 
@@ -168,8 +128,8 @@ void Resources::Private::addEvent(const Event & newEvent)
                     insertEvent(newEvent);
 
                     if (data.focussedResource.isEmpty()) {
-                        // This window haven't had anything focussed,
-                        // assuming the new document is focussed
+                        // This window haven't had anything focused,
+                        // assuming the new document is focused
 
                         data.focussedResource = newEvent.uri;
                         insertEvent(newEvent.deriveWithType(Event::FocussedIn));
@@ -228,16 +188,6 @@ void Resources::Private::addEvent(const Event & newEvent)
     start();
 }
 
-QList <KUrl> Resources::Private::resourcesLinkedToActivity(const QString & activity) const
-{
-    return doWithNepomukForActivity(activity, [] (const QString & activity)
-        {
-            return EXEC_NEPOMUK(resourcesLinkedToActivity(activity));
-        },
-        QList<KUrl>()
-    );
-}
-
 void Resources::Private::windowClosed(WId windowId)
 {
     // Testing whether the window is a registered one
@@ -262,7 +212,7 @@ void Resources::Private::windowClosed(WId windowId)
 
 void Resources::Private::activeWindowChanged(WId windowId)
 {
-    // If the focussed window has changed, we need to create a
+    // If the focused window has changed, we need to create a
     // FocussedOut event for the resource it contains,
     // and FocussedIn for the resource of the new active window.
     // The windows can do this manually, but if they are
@@ -315,6 +265,9 @@ Resources::~Resources()
 void Resources::RegisterResourceEvent(QString application, uint _windowId,
         const QString & uri, uint event, uint reason)
 {
+    Q_ASSERT_X(!uri.startsWith("nepomuk:"), "Resources::RegisterResourceEvent",
+            "We do not accept nepomuk URIs for resource events");
+
     if (
            event > Event::LastEventType
         || reason > Event::LastEventReason
@@ -328,8 +281,6 @@ void Resources::RegisterResourceEvent(QString application, uint _windowId,
     KUrl kuri(uri);
     WId windowId = (WId) _windowId;
 
-    EXEC_NEPOMUK( toRealUri(kuri) );
-
     d->addEvent(application, windowId,
             kuri.url(), (Event::Type) event, (Event::Reason) reason);
 }
@@ -341,8 +292,6 @@ void Resources::RegisterResourceMimeType(const QString & uri, const QString & mi
 
     KUrl kuri(uri);
 
-    EXEC_NEPOMUK( setResourceMimeType(KUrl(uri), mimetype) );
-
     emit RegisteredResourceMimeType(uri, mimetype);
 }
 
@@ -354,82 +303,12 @@ void Resources::RegisterResourceTitle(const QString & uri, const QString & title
 
     KUrl kuri(uri);
 
-    EXEC_NEPOMUK( setResourceTitle(KUrl(uri), title) );
-
     emit RegisteredResourceTitle(uri, title);
 }
 
-
-void Resources::LinkResourceToActivity(const QString & uri, const QString & activity)
-{
-    #ifdef HAVE_NEPOMUK
-    // Moves the files related to the activity to
-    // the private encrypted folder
-    if (Jobs::Encryption::Common::isActivityEncrypted(activity)) {
-        Jobs::Nepomuk::move(activity, true, QStringList() << uri)
-            ->create(this)->start();
-    }
-    #endif
-
-    // Links the resource to the activity
-    return doWithNepomukForActivity(activity, [&uri,this] (const QString & activity)
-        {
-            EXEC_NEPOMUK( linkResourceToActivity(KUrl(uri), activity) );
-            emit LinkedResourceToActivity(uri, activity);
-        }
-    );
-}
-
-
-void Resources::UnlinkResourceFromActivity(const QString & uri, const QString & activity)
-{
-    #ifdef HAVE_NEPOMUK
-    // Moves the files related to the activity from
-    // the private encrypted folder
-    if (Jobs::Encryption::Common::isActivityEncrypted(activity)) {
-        Jobs::Nepomuk::move(activity, true, QStringList() << uri)
-            ->create(this)->start();
-    }
-    #endif
-
-    // Unlinks the resource to the activity
-    return doWithNepomukForActivity(activity, [&uri,this] (const QString & activity)
-        {
-            EXEC_NEPOMUK( unlinkResourceFromActivity(KUrl(uri), activity) );
-            emit UnlinkedResourceFromActivity(uri, activity);
-        }
-    );
-}
-
-
-bool Resources::IsResourceLinkedToActivity(const QString & uri, const QString & activity) const
-{
-    return doWithNepomukForActivity(activity, [&uri] (const QString & activity)
-        {
-            return EXEC_NEPOMUK( isResourceLinkedToActivity(KUrl(uri), activity) );
-        },
-        /* default */ false
-    );
-}
-
-
-QStringList Resources::ResourcesLinkedToActivity(const QString & activity) const
-{
-    QStringList result;
-
-    foreach (const KUrl & uri, d->resourcesLinkedToActivity(activity)) {
-        result << uri.url();
-    }
-
-    return result;
-}
-
 bool Resources::isFeatureOperational(const QStringList & feature) const
 {
-    if (feature.first() == "linking") {
-        return NEPOMUK_PRESENT;
-    }
-
+    Q_UNUSED(feature)
     return false;
 }
 
@@ -449,7 +328,7 @@ void Resources::setFeatureEnabled(const QStringList & feature, bool value)
 QStringList Resources::listFeatures(const QStringList & feature) const
 {
     Q_UNUSED(feature)
-    static QStringList features("linking");
+    static QStringList features;
 
     return features;
 }
